@@ -25,7 +25,7 @@ __copyright__ = "Copyright (C) 2020 John Bumgarner"
 # Date Completed: October 15, 2020
 # Author: John Bumgarner
 #
-# Date Revised: June 1, 2021
+# Date Last Revised: July 4, 2021
 # Revised by: John Bumgarner
 #
 ##################################################################################
@@ -36,18 +36,20 @@ __copyright__ = "Copyright (C) 2020 John Bumgarner"
 temporary_dict_antonyms = {}
 
 
-def cache_antonyms(word, source):
-    item_to_check = f'{word}_{source}'
+def cache_antonyms(word):
+    item_to_check = f'{word}'
     if item_to_check in temporary_dict_antonyms.keys():
-        new_dict = {key: val for (key, val) in temporary_dict_antonyms.items() if key == word}
+        new_dict = {key: val for (key, val) in temporary_dict_antonyms.items() if key == item_to_check}
         return new_dict
     else:
         return False
 
 
-def insert_word_cache_antonyms(word, source, values):
-    key = f'{word}_{source}'
-    temporary_dict_antonyms[key] = values
+def insert_word_cache_antonyms(word, values):
+    if word in temporary_dict_antonyms:
+        temporary_dict_antonyms[word].append(values)
+    else:
+        temporary_dict_antonyms[word] = values
 
 
 ##################################################################################
@@ -56,8 +58,8 @@ def insert_word_cache_antonyms(word, source, values):
 temporary_dict_synonyms = {}
 
 
-def cache_synonyms(word, source):
-    item_to_check = f'{word}_{source}'
+def cache_synonyms(word):
+    item_to_check = f'{word}'
     if item_to_check in temporary_dict_synonyms.keys():
         new_dict = {key: val for (key, val) in temporary_dict_synonyms.items() if key == word}
         return new_dict
@@ -65,9 +67,11 @@ def cache_synonyms(word, source):
         return False
 
 
-def insert_word_cache_synonyms(word, source, values):
-    key = f'{word}_{source}'
-    temporary_dict_synonyms[key] = values
+def insert_word_cache_synonyms(word, values):
+    if word in temporary_dict_synonyms:
+        temporary_dict_synonyms[word].append(values)
+    else:
+        temporary_dict_synonyms[word] = values
 
 
 ##################################################################################
@@ -76,8 +80,8 @@ def insert_word_cache_synonyms(word, source, values):
 temporary_dict_definition = {}
 
 
-def cache_definition(word, source):
-    item_to_check = f'{word}_{source}'
+def cache_definition(word):
+    item_to_check = f'{word}'
     if item_to_check in temporary_dict_definition.keys():
         new_dict = {key: val for (key, val) in temporary_dict_synonyms.items() if key == word}
         return new_dict
@@ -85,9 +89,11 @@ def cache_definition(word, source):
         return False
 
 
-def insert_word_cache_definition(word, source, values):
-    key = f'{word}_{source}'
-    temporary_dict_definition[key] = values
+def insert_word_cache_definition(word, values):
+    if word in temporary_dict_definition:
+        temporary_dict_definition.update({word: values})
+    else:
+        temporary_dict_definition[word] = values
 
 
 ##################################################################################
@@ -96,8 +102,8 @@ def insert_word_cache_definition(word, source, values):
 temporary_dict_hypernyms = {}
 
 
-def cache_hypernyms(word, source):
-    item_to_check = f'{word}_{source}'
+def cache_hypernyms(word):
+    item_to_check = f'{word}'
     if item_to_check in temporary_dict_hypernyms.keys():
         new_dict = {key: val for (key, val) in temporary_dict_hypernyms.items() if key == word}
         return new_dict
@@ -105,9 +111,11 @@ def cache_hypernyms(word, source):
         return False
 
 
-def insert_word_cache_hypernyms(word, source, values):
-    key = f'{word}_{source}'
-    temporary_dict_hypernyms[key] = values
+def insert_word_cache_hypernyms(word, values):
+    if word in temporary_dict_hypernyms:
+        temporary_dict_hypernyms[word].append(values)
+    else:
+        temporary_dict_hypernyms[word] = values
 
 
 ##################################################################################
@@ -116,8 +124,8 @@ def insert_word_cache_hypernyms(word, source, values):
 temporary_dict_hyponyms = {}
 
 
-def cache_hyponyms(word, source):
-    item_to_check = f'{word}_{source}'
+def cache_hyponyms(word):
+    item_to_check = f'{word}'
     if item_to_check in temporary_dict_hyponyms.keys():
         new_dict = {key: val for (key, val) in temporary_dict_hyponyms.items() if key == word}
         return new_dict
@@ -125,7 +133,8 @@ def cache_hyponyms(word, source):
         return False
 
 
-def insert_word_cache_hyponyms(word, source, values):
-    key = f'{word}_{source}'
-    temporary_dict_hyponyms[key] = values
-
+def insert_word_cache_hyponyms(word, values):
+    if word in temporary_dict_hyponyms:
+        temporary_dict_hyponyms[word].append(values)
+    else:
+        temporary_dict_hyponyms[word] = values
