@@ -7,6 +7,7 @@ __author__ = 'John Bumgarner'
 __date__ = 'October 15, 2020'
 __status__ = 'Production'
 __license__ = 'MIT'
+__copyright__ = "Copyright (C) 2020 John Bumgarner"
 
 ##################################################################################
 # “AS-IS” Clause
@@ -18,6 +19,16 @@ __license__ = 'MIT'
 # purpose.
 ##################################################################################
 
+##################################################################################
+#
+# Date Completed: October 15, 2020
+# Author: John Bumgarner
+#
+# Date Revised:
+# Revised by:
+#
+##################################################################################
+
 ##################################################################################
 # Python imports required for basic operations
 ##################################################################################
@@ -38,7 +49,7 @@ def validate_word_syntax(word):
     if len(word) == 0:
         return False
     else:
-        temp = regex.match(r'^[a-zA-Z-]*$', word.strip())
+        temp = regex.match(r'^[a-zA-Z-\s]*$', word.strip())
         if temp:
             return True
         else:
